@@ -150,3 +150,8 @@ PipeOpLearner = R6Class("PipeOpLearner", inherit = PipeOp,
 )
 
 mlr_pipeops$add("learner", PipeOpLearner, list(R6Class("Learner", public = list(id = "learner", task_type = "classif", param_set = ParamSet$new()))$new()))
+
+#' @export
+as_learner.PipeOp = function(x, clone = FALSE) {
+  as_learner(as_graph(x))
+}
